@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -50,6 +50,9 @@ FAILEDOPERATION_GETSTREAMRESOLUTIONERROR = 'FailedOperation.GetStreamResolutionE
 # 无在线流。
 FAILEDOPERATION_HASNOTLIVINGSTREAM = 'FailedOperation.HasNotLivingStream'
 
+# 域名数量超过限制(100个）。
+FAILEDOPERATION_HOSTOUTLIMIT = 'FailedOperation.HostOutLimit'
+
 # 操作 CDN 接口失败。
 FAILEDOPERATION_INVOKECDNAPIFAIL = 'FailedOperation.InvokeCdnApiFail'
 
@@ -95,7 +98,7 @@ INTERNALERROR_CONFINUSED = 'InternalError.ConfInUsed'
 # 模版不存在。
 INTERNALERROR_CONFNOTFOUND = 'InternalError.ConfNotFound'
 
-# 模版数量超过显示。
+# 模版数量超过限制。
 INTERNALERROR_CONFOUTLIMIT = 'InternalError.ConfOutLimit'
 
 # 配置不存在。
@@ -272,6 +275,9 @@ INVALIDPARAMETER_DOMAINALREADYEXIST = 'InvalidParameter.DomainAlreadyExist'
 # 域名格式错误，请输入合法格式域名。
 INVALIDPARAMETER_DOMAINFORMATERROR = 'InvalidParameter.DomainFormatError'
 
+# 当前域名在黑名单中。
+INVALIDPARAMETER_DOMAINHITBLACKLIST = 'InvalidParameter.DomainHitBlackList'
+
 # 使用黑名单域名。
 INVALIDPARAMETER_DOMAINISFAMOUS = 'InvalidParameter.DomainIsFamous'
 
